@@ -41,8 +41,8 @@
  *   25: JS runtime did not report `process.version`.
  *   26: JS runtime returned a `process.version` that didn't match semver.
  */
-var pkg = require('../../package.json');
 
+var pkg = require('../../package.json');
 var versionMatcher = /^\s*v?\s*(\d+)(?:\.(\d+))?(?:\.(\d+))?(?:\D.*)?$/;
 var rangeMatcher = /^\s*(>=?|\^|~|=)?\s*(\d+)(?:\.(\d+))?(?:\.(\d+))?(?:[^\d.].*)?$/;
 var ERR_MISSING_REQUIREMENTS = 'OpenSearch Dashboards did not report its required version of the Node.js runtime';
@@ -51,11 +51,11 @@ var _BAD_REQUIREMENTS_SUFFIX = '. Please revert any changes that might have been
 ERR_MISSING_REQUIREMENTS += _BAD_REQUIREMENTS_SUFFIX;
 ERR_BAD_REQUIREMENTS += _BAD_REQUIREMENTS_SUFFIX;
 var pkgEngineNodeVersion = pkg && pkg.engines && pkg.engines.node;
-
 if (!pkgEngineNodeVersion || typeof pkgEngineNodeVersion !== 'string') {
   console.error(ERR_MISSING_REQUIREMENTS);
   process.exit(22);
 }
+
 /* Basic semver parsing: This is a very limited subset of what semver supports where only a single comparator, composed
  * of an operator and a version, is supported.
  * [https://github.com/npm/node-semver/blob/cb1ca1d5480a6c07c12ac31ba5f2071ed530c4ed/README.md#ranges]
@@ -70,15 +70,11 @@ if (!pkgEngineNodeVersion || typeof pkgEngineNodeVersion !== 'string') {
  *
  * Note: If no operator is specified, equality is assumed.
  */
-
-
 var requiredParts = pkgEngineNodeVersion.match(rangeMatcher);
-
 if (requiredParts === null) {
   console.error(ERR_BAD_REQUIREMENTS);
   process.exit(23);
 }
-
 var comparatorVersion = {
   major: requiredParts[2],
   minor: requiredParts[3],
@@ -92,12 +88,10 @@ var rangeBottom = {
   inclusive: comparatorOperator.indexOf('>') === -1 || comparatorOperator.indexOf('=') > -1
 };
 var rangeTop = undefined;
-
 if (!rangeBottom.major) {
   console.error(ERR_BAD_REQUIREMENTS);
   process.exit(24);
 }
-
 if (comparatorOperator === '>') {
   if (!comparatorVersion.minor) {
     // >3 is >=4.0.0
@@ -108,14 +102,14 @@ if (comparatorOperator === '>') {
     rangeBottom.minor += 1;
     rangeBottom.inclusive = true;
   }
-} // =3 is ~3.0.0 and =3.1 is ~3.1.0
-
+}
 
+// =3 is ~3.0.0 and =3.1 is ~3.1.0
 if (comparatorOperator === '=' && (!comparatorVersion.minor || !comparatorVersion.patch)) {
   comparatorOperator = '~';
-} // =3.1.4
-
+}
 
+// =3.1.4
 if (comparatorOperator === '=') {
   rangeTop = {
     major: rangeBottom.major,
@@ -147,80 +141,71 @@ if (comparatorOperator === '=') {
     patch: 0
   };
 }
-
 function getVersionCompatibilityMessage() {
   var versionBottom = 'v' + rangeBottom.major + '.' + rangeBottom.minor + '.' + rangeBottom.patch;
-
   if (comparatorOperator === '=') {
     return 'Please use Node.js ' + versionBottom + '.';
   }
-
   var message = 'Please use a Node.js runtime version that is greater than ' + versionBottom;
-
   if (rangeBottom.inclusive) {
     message = 'Please use a Node.js runtime version that is ' + versionBottom + ' or greater';
   }
-
   if (!rangeTop) return message + '.';
-  var versionTop = 'v' + rangeTop.major + '.' + rangeTop.minor + '.' + rangeTop.patch; // The only operator with a truthy `rangeTop.inclusive` is the `=` which was handled above
-
+  var versionTop = 'v' + rangeTop.major + '.' + rangeTop.minor + '.' + rangeTop.patch;
+  // The only operator with a truthy `rangeTop.inclusive` is the `=` which was handled above
   return message + ' and lower than ' + versionTop + '.';
 }
+
 /* Compares the 2 versions and returns
  *   1: A  >  B
  *   0: A === B
  *  -1: A  <  B
  */
-
-
 function versionCompare(versionA, versionB) {
   // 4.x.x > 3.1.4
   if (versionA.major > versionB.major) return 1;else if (versionA.major === versionB.major) {
     // 3.2.x > 3.1.4
     if (versionA.minor > versionB.minor) return 1;else if (versionA.minor === versionB.minor) {
       // 3.1.5 >= 3.1.4
-      if (versionA.patch > versionB.patch) return 1; // 3.1.4 = 3.1.4
+      if (versionA.patch > versionB.patch) return 1;
+      // 3.1.4 = 3.1.4
       else if (versionA.patch === versionB.patch) return 0;
     }
   }
   return -1;
 }
-
 if (false) {
 
 var currentVersion = process && process.version;
-
 if (!currentVersion) {
   console.error('OpenSearch Dashboards cannot start up because the JavaScript runtime did not report its version. ' + getVersionCompatibilityMessage());
   process.exit(25);
 }
-
 var currentParts = currentVersion.match(versionMatcher);
-
 if (currentParts === null) {
   console.error('OpenSearch Dashboards cannot start up because the JavaScript runtime did not report its version in a ' + 'discernible format. ' + getVersionCompatibilityMessage());
   process.exit(26);
 }
-
 var version = {
   major: parseInt(currentParts[1], 10) || 0,
   minor: parseInt(currentParts[2], 10) || 0,
   patch: parseInt(currentParts[3], 10) || 0
 };
-var satisfiesBottom = false; // Check if version is greater than rangeBottom or if equal, that `rangeBottom` is inclusive
+var satisfiesBottom = false;
 
+// Check if version is greater than rangeBottom or if equal, that `rangeBottom` is inclusive
 var versionComparedToRangeBottom = versionCompare(version, rangeBottom);
 if (versionComparedToRangeBottom === 1) satisfiesBottom = true;else if (rangeBottom.inclusive && versionComparedToRangeBottom === 0) satisfiesBottom = true;
 var satisfiesTop = false;
-
 if (satisfiesBottom && rangeTop) {
   var versionComparedToRangeTop = versionCompare(version, rangeTop);
   if (versionComparedToRangeTop === -1) satisfiesTop = true;else if (rangeTop.inclusive && versionComparedToRangeTop === 0) satisfiesTop = true;
-} // Fail if the Node.js version doesn't satisfy the requirements of OpenSearch Dashboards
-
+}
 
+// Fail if the Node.js version doesn't satisfy the requirements of OpenSearch Dashboards
 if (!satisfiesBottom || rangeTop && !satisfiesTop) {
   console.error('OpenSearch Dashboards cannot start up using the Node.js runtime v' + version.major + '.' + version.minor + '.' + version.patch + '. ' + getVersionCompatibilityMessage());
   process.exit(21);
 }
+
 }
